@@ -190,6 +190,7 @@ pub enum ScreenContext {
     SwitchFocus,
     FocusNextPane,
     FocusPreviousPane,
+    FocusPaneAt,
     MoveFocusLeft,
     MoveFocusLeftOrPreviousTab,
     MoveFocusDown,
@@ -198,13 +199,17 @@ pub enum ScreenContext {
     MoveFocusRightOrNextTab,
     Exit,
     ScrollUp,
+    ScrollUpAt,
     ScrollDown,
+    ScrollDownAt,
+    ScrollToBottom,
     PageScrollUp,
     PageScrollDown,
     ClearScroll,
     CloseFocusedPane,
     ToggleActiveSyncTab,
     ToggleActiveTerminalFullscreen,
+    TogglePaneFrames,
     SetSelectable,
     SetInvisibleBorders,
     SetFixedHeight,
@@ -219,6 +224,11 @@ pub enum ScreenContext {
     UpdateTabName,
     TerminalResize,
     ChangeMode,
+    LeftClick,
+    MouseRelease,
+    MouseHold,
+    Copy,
+    ToggleTab,
 }
 
 /// Stack call representations corresponding to the different types of [`PtyInstruction`]s.
